@@ -10,7 +10,7 @@
  */
 /*
  *  This file is part of AutoGen.
- *  Copyright (C) 1992-2018 Bruce Korb - all rights reserved
+ *  Copyright (C) 1992-2020 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -26,21 +26,7 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-static char const * ld_lib_path = NULL;
-
-/* = = = START-STATIC-FORWARD = = = */
-static void
-init_scm(void);
-
-static char const *
-make_quote_str(char const * str);
-
-static void
-dep_usage(char const * fmt, ...);
-
-static void
-add_sys_env(char * env_name);
-/* = = = END-STATIC-FORWARD = = = */
+ static char const * ld_lib_path = NULL;
 
 #include "expr.ini"
 
@@ -50,7 +36,7 @@ add_sys_env(char * env_name);
  * @param arg_ct  the count of program arguments, plus 1.
  * @param arg_vec the program name plus its arguments
  */
-LOCAL void
+static void
 initialize(int arg_ct, char ** arg_vec)
 {
     putenv(C(char *, ld_lib_path));
@@ -73,6 +59,26 @@ initialize(int arg_ct, char ** arg_vec)
         SCM_EVAL_CONST(INIT_SCM_DEBUG_FMT);
 }
 
+
+/**
+ * extract the base name of a file
+ *
+ * @param fname name of the file
+ * @returns a pointer to where the base file name starts
+ */
+static char const *
+ag_basename( char const * fname )
+{
+    char const * res = strrchr(fname, DIRCH);
+    if (res == NULL)
+        return fname;
+    return res + 1;
+}
+
+
+/**
+ * Feed the initializing instructions to the SCM interpreter
+ */
 static void
 init_scm(void)
 {
@@ -83,35 +89,6 @@ init_scm(void)
             SCHEME_INIT_TEXT, AG_TEXT_STRTABLE_FILE, SCHEME_INIT_TEXT_LINENO);
         AGDUPSTR(libguile_ver, scm2display(ini_res), "ini res");
     }
-
-    {
-        unsigned int maj, min, mic;
-        switch (sscanf(libguile_ver, "%u.%u.%u", &maj, &min, &mic)) {
-        case 2:
-        case 3: break;
-        default:
-            AG_ABEND(aprf(GUILE_VERSION_BAD, libguile_ver));
-            /* NOT_REACHED */
-        }
-        maj = min + (100 * maj);
-        if ((GUILE_VERSION / 1000) != maj)
-            AG_ABEND(aprf(GUILE_VERSION_WRONG, libguile_ver,
-                          MK_STR(GUILE_VERSION)));
-    }
-
-    {
-#       if GUILE_VERSION >= 200000
-#         define SCHEME_INIT_DEBUG SCHEME_INIT_DEBUG_2_0
-#       else
-#         define SCHEME_INIT_DEBUG SCHEME_INIT_DEBUG_1_6
-#       endif
-        char * p = aprf(INIT_SCM_ERRS_FMT, SCHEME_INIT_DEBUG);
-#       undef  SCHEME_INIT_DEBUG
-
-        last_scm_cmd = p;
-        ag_scm_c_eval_string_from_file_line(p, __FILE__, __LINE__);
-        AGFREE(p);
-    }
 }
 
 /**
@@ -184,7 +161,7 @@ dep_usage(char const * fmt, ...)
  * @param opts the autogen options data structure
  * @param pOptDesc the option descriptor for this option.
  */
-LOCAL void
+static void
 config_dep(tOptions * opts, tOptDesc * od)
 {
     char const * opt_arg = od->optArg.argString;
@@ -286,7 +263,7 @@ add_sys_env(char * env_name)
  * to match what we currently have.  Additionally, force our environment
  * to be "C" and export all the variables that describe our system.
  */
-LOCAL void
+static void
 prep_env(void)
 {
     /*
