@@ -1,6 +1,6 @@
 
 /**
- *  @file autogen.c
+ * @file autogen.c
  *
  *  This is the main routine for autogen.
  *  @addtogroup autogen
@@ -8,7 +8,7 @@
  */
 
 /*  This file is part of AutoGen.
- *  Copyright (C) 1992-2018 Bruce Korb - all rights reserved
+ *  Copyright (C) 1992-2020 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -44,41 +44,25 @@ typedef enum {
 } wait_for_pclose_enum_t;
 
 #define _State_(n)  #n,
-static char const * const state_names[] = { STATE_TABLE };
+ static char const * const state_names[] = { STATE_TABLE };
 #undef _State_
 
 typedef void (sighandler_proc_t)(int sig);
-static sighandler_proc_t ignore_signal, catch_sig_and_bail;
-
-/* = = = START-STATIC-FORWARD = = = */
-static void
-inner_main(void * closure, int argc, char ** argv);
-
-static void
-exit_cleanup(wait_for_pclose_enum_t cl_wait);
-
-static _Noreturn void
-cleanup_and_abort(int sig);
-
-static void
-catch_sig_and_bail(int sig);
-
-static void
-ignore_signal(int sig);
-
-static void
-done_check(void);
-
-static void
-setup_signals(sighandler_proc_t * hdl_chld,
-              sighandler_proc_t * hdl_abrt,
-              sighandler_proc_t * hdl_dflt);
-/* = = = END-STATIC-FORWARD = = = */
+ static sighandler_proc_t ignore_signal, catch_sig_and_bail;
 
 #ifndef HAVE_CHMOD
 #  include "compat/chmod.c"
 #endif
 
+MOD_LOCAL void
+setup_signals(sighandler_proc_t * hdl_chld,
+              sighandler_proc_t * hdl_abrt,
+              sighandler_proc_t * hdl_dflt);
+MOD_LOCAL void
+inner_main(void * closure, int argc, char ** argv);
+MOD_LOCAL void
+exit_cleanup(wait_for_pclose_enum_t cl_wait);
+
 /**
  * main routine under Guile guidance
  *
@@ -86,9 +70,10 @@ setup_signals(sighandler_proc_t * hdl_chld,
  * @param  argc    argument count
  * @param  argv    argument vector
  */
-static void
+MOD_LOCAL void
 inner_main(void * closure, int argc, char ** argv)
 {
+    (void)closure;
     atexit(done_check);
     initialize(argc, argv);
 
@@ -115,8 +100,6 @@ inner_main(void * closure, int argc, char ** argv)
     setup_signals(SIG_DFL, SIG_IGN, SIG_DFL);
     ag_exit_code = AUTOGEN_EXIT_SUCCESS;
     done_check();
-    /* NOTREACHED */
-    (void)closure;
 }
 
 /**
@@ -129,6 +112,10 @@ inner_main(void * closure, int argc, char ** argv)
 int
 main(int argc, char ** argv)
 {
+    /*
+     * Things just don't work right in the Guile library if we're not
+     * in the "C" language environment. If we are not, then start over.
+     */
     {
         char const * lc = getenv("LC_ALL");
         if ((lc != NULL) && (*lc != NUL) && (strcmp(lc, "C") != 0)) {
@@ -156,7 +143,7 @@ main(int argc, char ** argv)
  *
  * @param [in] cl_wait Whether or not a child process should be waited for.
  */
-static void
+MOD_LOCAL void
 exit_cleanup(wait_for_pclose_enum_t cl_wait)
 {
     /*
@@ -214,7 +201,7 @@ exit_cleanup(wait_for_pclose_enum_t cl_wait)
  *
  *  @param[in] sig the signal number
  */
-static _Noreturn void
+static noreturn void
 cleanup_and_abort(int sig)
 {
     if (processing_state == PROC_STATE_INIT) {
@@ -235,7 +222,7 @@ cleanup_and_abort(int sig)
         exit_cleanup(EXIT_PCLOSE_NOWAIT);
 
         if (HAVE_OPT(NO_ABORT))
-            exit(AUTOGEN_EXIT_USAGE_ERROR);
+            exit(AUTOGEN_EXIT_SYSEXIT_USAGE);
         abort();
     }
 
@@ -287,7 +274,7 @@ cleanup_and_abort(int sig)
     exit_cleanup(EXIT_PCLOSE_NOWAIT);
 
     if (HAVE_OPT(NO_ABORT))
-        exit(AUTOGEN_EXIT_USAGE_ERROR);
+        exit(AUTOGEN_EXIT_SYSEXIT_USAGE);
     abort();
 }
 
@@ -465,7 +452,7 @@ done_check(void)
 }
 
 
-LOCAL _Noreturn void
+static noreturn void
 ag_abend_at(char const * msg
 #ifdef DEBUG_ENABLED
             , char const * fname, int line
@@ -491,7 +478,7 @@ ag_abend_at(char const * msg
         fputc(NL, stderr);
 
     if (HAVE_OPT(NO_ABORT))
-        exit(AUTOGEN_EXIT_USAGE_ERROR);
+        exit(AUTOGEN_EXIT_SYSEXIT_USAGE);
 
 #ifdef DEBUG_ENABLED
     abort();
@@ -514,7 +501,7 @@ ag_abend_at(char const * msg
 #endif
 }
 
-static void
+MOD_LOCAL void
 setup_signals(sighandler_proc_t * hdl_chld,
               sighandler_proc_t * hdl_abrt,
               sighandler_proc_t * hdl_dflt)
@@ -604,7 +591,7 @@ setup_signals(sighandler_proc_t * hdl_chld,
 #  include <compat/strsignal.c>
 #endif
 
-LOCAL void *
+static void *
 ao_malloc (size_t sz)
 {
     void * res = malloc(sz);
@@ -614,7 +601,7 @@ ao_malloc (size_t sz)
 }
 
 
-LOCAL void *
+static void *
 ao_realloc (void *p, size_t sz)
 {
     void * res = (p == NULL) ? malloc(sz) : realloc(p, sz);
@@ -623,8 +610,8 @@ ao_realloc (void *p, size_t sz)
     return res;
 }
 
-LOCAL char *
-ao_strdup (char const * str)
+static char *
+ao_strdup(char const * str)
 {
     char * res = strdup(str);
     if (res == NULL)
