@@ -1,3 +1,4 @@
+
 /**
  * @file expExtract.c
  *
@@ -8,7 +9,7 @@
  */
 /*
  *  This file is part of AutoGen.
- *  AutoGen Copyright (C) 1992-2018 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2020 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -24,18 +25,7 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* = = = START-STATIC-FORWARD = = = */
-static char const *
-load_extract_file(char const * new_fil);
-
-static SCM
-mk_empty_text(char const * start, char const * end, SCM def);
-
-static SCM
-get_text(char const * text, char const * start, char const * end, SCM def);
-/* = = = END-STATIC-FORWARD = = = */
-
-LOCAL char *
+static char *
 load_file(char const * fname)
 {
     char * res = NULL;
@@ -56,10 +46,15 @@ load_file(char const * fname)
 
         fsz = stbf.st_size;
         res = (char *)AGALOC(fsz + 1, "load_file");
-        if (time_is_before(outfile_time, stbf.st_mtime))
-            outfile_time = stbf.st_mtime;
-        if (time_is_before(maxfile_time, stbf.st_mtime))
-            maxfile_time = stbf.st_mtime;
+        if (time_is_before(outfile_time, stbf))
+            outfile_time = (struct timespec) {
+                .tv_sec  = (unsigned long)stbf.st_mtime,
+                .tv_nsec = ST_MTIME_NSEC(stbf) };
+        
+        if (time_is_before(maxfile_time, stbf))
+            maxfile_time = (struct timespec) {
+                .tv_sec  = (unsigned long)stbf.st_mtime,
+                .tv_nsec = ST_MTIME_NSEC(stbf) };
     }
 
     {
@@ -173,7 +168,7 @@ mk_empty_text(char const * start, char const * end, SCM def)
         sprintf(pzOut, LINE_CONCAT3_FMT, start, pzDef, end);
     }
 
-    return scm_from_latin1_string(pzOut);
+    return AG_SCM_FROM_STR(pzOut);
 }
 
 
@@ -195,7 +190,7 @@ get_text(char const * text, char const * start, char const * end, SCM def)
 
     pzE += strlen(end);
 
-    return scm_from_latin1_stringn(pzS, (size_t)(pzE - pzS));
+    return AG_SCM_FROM_STRN(pzS, (size_t)(pzE - pzS));
 }
 
 
@@ -358,10 +353,10 @@ ag_scm_find_file(SCM file, SCM suffix)
             apz[0] = (char *)ag_scm2zchars(suffix, "file suffix");
             apz[1] = NULL;
             if (SUCCESSFUL(find_file(pz, z, (char const **)apz, NULL)))
-                res = scm_from_latin1_string(z);
+                res = AG_SCM_FROM_STR(z);
 
         } else if (SUCCESSFUL(find_file(pz, z, NULL, NULL)))
-            res = scm_from_latin1_string(z);
+            res = AG_SCM_FROM_STR(z);
     }
 
     return res;
