@@ -13,7 +13,7 @@
  */
 /*
  *  This file is part of AutoGen.
- *  AutoGen Copyright (C) 1992-2018 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2020 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -29,16 +29,9 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #ifndef DEBUG_ENABLED
-static sigjmp_buf printJumpEnv;
-static int        printJumpSignal = 0;
-#endif
+ static sigjmp_buf printJumpEnv;
+ static int        printJumpSignal = 0;
 
-/* = = = START-STATIC-FORWARD = = = */
-static ssize_t
-safePrintf(char ** ppzBuf, char const * pzFmt, void ** argV);
-/* = = = END-STATIC-FORWARD = = = */
-
-#ifndef DEBUG_ENABLED
  static void printFault(int sig)
 {
     printJumpSignal = sig;
@@ -107,8 +100,7 @@ safePrintf(char ** ppzBuf, char const * pzFmt, void ** argV)
     }
 }
 
-
-LOCAL SCM
+static SCM
 run_printf(char const * pzFmt, int len, SCM alist)
 {
     SCM     res;
@@ -172,7 +164,7 @@ run_printf(char const * pzFmt, int len, SCM alist)
     {
         char *  bf;
         size_t  bf_sz = (size_t)safePrintf(&bf, pzFmt, arglist);
-        res = scm_from_latin1_stringn(bf, bf_sz);
+        res = AG_SCM_FROM_STRN(bf, bf_sz);
         free(bf);
     }
 
@@ -292,7 +284,7 @@ ag_scm_hide_email(SCM display, SCM eaddr)
     if (scan > end)
         AG_ABEND(BOGUS_TAG);
 
-    return scm_from_latin1_stringn(res, (size_t)(scan - res));
+    return AG_SCM_FROM_STRN(res, (size_t)(scan - res));
 }
 
 /*=gfunc   format_arg_count
